@@ -5,6 +5,7 @@ import json
 import logging
 
 from dateutil.parser import parse as date_parse
+from requests.utils import requote_uri
 import github3
 import gitlab
 
@@ -22,6 +23,7 @@ class Metadata(dict):
 
     For details: https://code.gov/#/policy-guide/docs/compliance/inventory-code
     """
+
     def __init__(self, agency, method, other_method=''):
         # *version: [string] The Code.gov metadata schema version
         self['version'] = '2.0.0'
@@ -48,7 +50,7 @@ class Metadata(dict):
         self['releases'] = []
 
     def to_json(self):
-        return json.dumps(self, indent=4, sort_keys=True)
+        return json.dumps(self, indent=4, sort_keys=True, ensure_ascii=False)
 
 
 class Project(dict):
@@ -177,7 +179,7 @@ class Project(dict):
         """
         Create CodeGovProject object from github3 Repository object
         """
-        if not isinstance(repository, github3.repos.repo.Repository):
+        if not isinstance(repository, github3.repos.repo._Repository):
             raise TypeError('Repository must be a github3 Repository object')
 
         logger.info('Processing: %s', repository.full_name)
@@ -192,8 +194,22 @@ class Project(dict):
         project['repositoryURL'] = repository.git_url
         project['description'] = repository.description
 
-        # TODO: Update licenses from GitHub API
-        project['permissions']['licenses'] = None
+        try:
+            repo_license = repository.license()
+        except github3.exceptions.NotFoundError:
+            logger.debug('no license found for repo=%s', repository)
+            repo_license = None
+
+        if repo_license:
+            license = repo_license.license
+            if license:
+                logger.debug('license spdx=%s; url=%s', license.spdx_id, license.url)
+                if license.url is None:
+                    project['permissions']['licenses'] = [{"name": license.spdx_id}]
+                else:
+                    project['permissions']['licenses'] = [{"URL": license.url, "name": license.spdx_id}]
+            else:
+                project['permissions']['licenses'] = None
 
         public_server = repository.html_url.startswith('https://github.com')
         if not repository.private and public_server:
@@ -210,18 +226,21 @@ class Project(dict):
         old_accept = repository.session.headers['Accept']
         repository.session.headers['Accept'] = 'application/vnd.github.mercy-preview+json'
         topics = repository._get(repository.url + '/topics').json()
-        project['tags'].extend(topics['names'])
+        project['tags'].extend(topics.get('names', []))
         repository.session.headers['Accept'] = old_accept
 
-        organization = repository.owner
-        project['contact']['email'] = organization.email
-        project['contact']['URL'] = organization.html_url
+        # Hacky way to get an Organization object back with GitHub3.py >= 1.2.0
+        owner_url = repository.owner.url
+        owner_api_response = repository._get(owner_url)
+        organization = repository._json(owner_api_response, 200)
+        project['contact']['email'] = organization['email']
+        project['contact']['URL'] = organization['html_url']
 
         # -- OPTIONAL FIELDS --
 
         # project['version'] = ''
 
-        project['organization'] = organization.name
+        project['organization'] = organization['name']
 
         # TODO: Currently, can't be an empty string, see: https://github.com/GSA/code-gov-web/issues/370
         project['status'] = 'Development'
@@ -230,7 +249,7 @@ class Project(dict):
 
         project['homepageURL'] = repository.html_url
 
-        project['downloadURL'] = repository.download_url
+        project['downloadURL'] = repository.downloads_url
 
         project['languages'] = [l for l, _ in repository.languages()]
 
@@ -244,9 +263,18 @@ class Project(dict):
         #   created: [string] The date the release was originally created, in YYYY-MM-DD or ISO 8601 format.
         #   lastModified: [string] The date the release was modified, in YYYY-MM-DD or ISO 8601 format.
         #   metadataLastUpdated: [string] The date the metadata of the release was last updated, in YYYY-MM-DD or ISO 8601 format.
+        try:
+            created_at = repository.created_at.date()
+        except AttributeError:
+            created_at = date_parse(repository.created_at).date()
+        try:
+            updated_at = repository.updated_at.date()
+        except AttributeError:
+            updated_at = date_parse(repository.updated_at).date()
+
         project['date'] = {
-            'created': repository.pushed_at.isoformat(),
-            'lastModified': repository.updated_at.isoformat(),
+            'created': created_at.isoformat(),
+            'lastModified': updated_at.isoformat(),
             'metadataLastUpdated': '',
         }
 
@@ -276,7 +304,8 @@ class Project(dict):
         project['repositoryURL'] = repository.http_url_to_repo
         project['description'] = repository.description
 
-        project['permissions']['license'] = None
+        # TODO: Update licenses from GitLab API
+        project['permissions']['licenses'] = None
 
         web_url = repository.web_url
         public_server = web_url.startswith('https://gitlab.com')
@@ -321,8 +350,8 @@ class Project(dict):
         # project['reusedCode'] = []
 
         project['date'] = {
-            'created': repository.created_at,
-            'lastModified': repository.last_activity_at,
+            'created': date_parse(repository.created_at).date().isoformat(),
+            'lastModified': date_parse(repository.last_activity_at).date().isoformat(),
             'metadataLastUpdated': '',
         }
 
@@ -542,3 +571,58 @@ class Project(dict):
             }
 
         return project
+
+    @classmethod
+    def from_tfs(klass, tfs_project, labor_hours=True):
+        """
+        Creates CodeGovProject object from TFS/VSTS/AzureDevOps Instance
+        """
+        project = klass()
+        project_web_url = ''
+
+        # -- REQUIRED FIELDS --
+        project['name'] = tfs_project.projectInfo.name
+
+        if 'web' in tfs_project.projectInfo._links.additional_properties:
+            if 'href' in tfs_project.projectInfo._links.additional_properties['web']:
+                # URL Encodes spaces that are in the Project Name for the Project Web URL
+                project_web_url = requote_uri(tfs_project.projectInfo._links.additional_properties['web']['href'])
+
+        project['repositoryURL'] = project_web_url
+
+        project['homepageURL'] = project_web_url
+
+        project['description'] = tfs_project.projectInfo.description
+
+        project['vcs'] = 'TFS/AzureDevOps'
+
+        project['permissions']['license'] = None
+
+        project['tags'] = []
+
+        if labor_hours:
+            logger.debug('Sorry labor hour calculation not currently supported.')
+            # project['laborHours'] = labor_hours_from_url(project['repositoryURL'])
+        else:
+            project['laborHours'] = 0
+
+        if tfs_project.projectCreateInfo.last_update_time < POLICY_START_DATE:
+            project['permissions']['usageType'] = 'exemptByPolicyDate'
+        else:
+            project['permissions']['usageType'] = 'exemptByAgencyMission'
+            project['permissions']['exemptionText'] = 'This source code resides on a private server and has not been properly evaluated for releaseability.'
+
+        project['contact'] = {
+            'email': '',
+            'URL': project_web_url
+        }
+
+        project['date'] = {
+            'lastModified': tfs_project.projectLastUpdateInfo.last_update_time.date().isoformat(),
+            'created': tfs_project.projectCreateInfo.last_update_time.date().isoformat(),
+            'metadataLastUpdated': ''
+        }
+
+        _prune_dict_null_str(project)
+
+        return project
